@@ -18,7 +18,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw($activcount
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} }, "server_info" );
 
 our @EXPORT = qw();
-our $VERSION = '0.04';
+our $VERSION = '0.08';
 
 #sub AUTOLOAD {
 #    # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -145,6 +145,34 @@ sub prepare {
  return $self;
 }
 
+#--- Open a segmented request. No input variables.
+sub openseg {
+ my ($ch, $sql, $save_spl) = @_;
+ if ($ch->{htype} ne 'conn') {
+    Carp::carp "Invalid handle passed to open";
+    return 0;
+ }
+ $sql =~ tr/\r/ /;
+ $save_spl = uc($save_spl || 'Y'),
+
+ my $self = {
+    htype => 'req',  # I am a request handle.
+    sess_id => $ch->{'sess_id'},
+    sql => $sql,
+    save_spl => $save_spl,
+ };
+
+ my $req_id = Xopenseg($ch->{sess_id}, $sql, $save_spl);
+
+ if ( $req_id != 0 ) {
+    $self->{'req_id'} = $req_id;
+    bless $self, 'Teradata::SQL';
+    return $self;
+ } else {
+    return undef;
+ }
+}
+
 #--- Execute a prepared request (no data returned).  May have arguments.
 sub executep {
  my ($rh, @hvars) = @_;
@@ -318,6 +346,13 @@ use B<prepare> instead.
 
 open returns a request handle or, if the open fails, undef.
 
+An open/fetch/close sequence fetches all the rows from a request.
+If there are multiple statements in the request, it will fetch
+all rows from all result sets. In this case, the activity count
+will show the number of rows in each result set, not in all of
+them combined. Its value will change at the beginning of each
+result set (see L<"Variables">).  
+
 After fetching all the rows, be sure to close() the cursor.
 
 =item B<prepare> REQUEST
@@ -371,6 +406,30 @@ See the CLIv2 Reference, s.v. "PrepInfo Parcel".
 Request method. Closes the cursor. This should always be called
 after opening and fetching the results.
 
+=item B<openseg> REQUEST [SAVE_SPL]
+
+Connection method. Opens a request for execution in segments.
+This method can be used only for compiling stored procedures.
+Currently it is limited to only one segment, so the entire text of
+the procedure must be passed at once. Be sure that the length of
+the text is within the limit returned by QEPIDMSS (item 11; see
+L<"server_info">).
+
+The optional second argument is 'Y' if you wish to save the stored
+procedure text in the database, 'N' otherwise. The default is 'Y'.
+
+The same rules apply as for open(). If the request succeeds, no
+rows will be returned, but if it fails error messages will be
+returned. You should therefore run fetchrow_list() and close()
+as usual after issuing the request.
+
+=item B<dec_digits> N
+
+Connection method. Sets the maximum number of decimal digits to be
+returned to N. This is similar to the DECIMALDIGITS command in BTEQ.
+See, however, the section L<"Data Types"> for notes about large
+decimal values.
+
 =item B<abort>
 
 Connection method. Aborts the currently active request for the session.
@@ -444,6 +503,11 @@ For more examples, see test.pl.
 Activity count, i.e. the number of rows affected by the last
 SQL operation. This variable can be exported to your namespace.
 
+If a multi-statement request has been processed, the activity
+count will take on multiple values, one for each statement.
+These values can be seen as each row is fetched from the 
+result sets.
+
 =item B<$Teradata::SQL::errorcode>
 
 The Teradata error code from the last SQL operation.
@@ -477,7 +541,7 @@ The data returned from Teradata will be converted to one of
 these types and will look like ordinary Perl values.
 
 Dates are returned in either integer form (e.g., 1020815 for
-15 August 2002) or in ANSI character form (e.g., '2002-08-15'),
+15 August 2002) or ANSI character form (e.g., '2002-08-15'),
 depending on the default for your system, the session
 characteristics, and whether you have issued a SET
 SESSION DATEFORM request. If you want dates returned in some
@@ -489,17 +553,28 @@ By default, times and timestamps are returned as character
 strings in their default formats. Again, you can cast them
 as you wish in your select request.
 
-A word of caution is in order about decimal fields.
+A word of caution is in order about decimal fields and
+bigints.
 Decimal fields with a precision of 9 or lower will be
 converted to doubles (numeric) and will behave more or less
 as expected, with the usual caveats about floating-point
-arithmetic. Decimal fields with a higher precision (10-18 digits)
+arithmetic. Decimal fields with a higher precision (10-18 digits),
+as well as bigints,
 will be converted to character strings. This has the advantage
 of preserving their full precision, but it means that Perl
 will not treat them as numeric. To convert them to numeric
 fields, you can add 0 to them, but values with 16 or more
 significant digits will lose precision. You have been warned!
 
+Decimal fields of more than 18 digits are not supported.
+If they are returned from the database, the module will issue
+a warning and substitute a 0 in their place. (This warning
+will not appear if msglevel is 0.)
+You should instead ask the database to convert
+them to strings, e.g. like this:
+
+   cast(cast(large_dec as format '-(30)9.99') as varchar(40))
+
 Arguments passed to Teradata via B<openp> and B<executep> will
 be passed in Perl internal form (integer, double, or byte
 string). You can pass undefs to become nulls in the database, but
@@ -557,7 +632,7 @@ the address shown below. No guarantees!
 =head1 Reference
 
 Teradata Call-Level Interface Version 2 Reference for
-Network-Attached Systems, B035-2418-096A (Sep. 2006).
+Network-Attached Systems, Release 13, B035-2418-088A (Aug. 2008).
 
 =head1 Author
 
